---
topic: Extensions
---
# Step 2: Add extensions to ImmunizationProfile ➕

<ul class="roundbox">
<p>Not all required information is present in the core Immunization resource. The following addition requirments are made.</p>
<ol>
<li> The medicine regulatory authority (MRA) needs to know the performed vaccination procedure.</li>
<li> The MRA needs to have all the specific details of the administrated vaccine product. Although the vaccineCode and other relevant elements of Immunization provide essential information the Medication resource is more suitable for all the requirements.</li>
</ol>
</ul>

## Step 2.1: Reuse an extension: ExtensionUKCoreVaccinationProcedure 
A search in the [FHIR Registry][1] and [Simplifier.net][2] revealed that HL7 UK published an extension to capture information about the vaccination procedure in a coded way. It is named ExtensionUKCoreVaccinationProcedure. We are going to reuse that extension. 


HL7 UK published the [ExtensionUKCoreVaccinationProcedure][3] in a FHIR package. That makes it even easier for us to include the extension. 
*   Examine the extension and see where the extension is allowed to be used to see if it fits.
*   In Forge, select your profiling folder and go to the dependencies tab
*   Hit the Simplifier icon
*   Search for `Uk.Core.r4`
*   Install version 1.3.0 by selecting it and clicking on ‘Add’

Nice! You have downloaded all the published HL7 UK profiles and it's dependencies (in this case also the HL7 FHIR R4 core resources) to your local package cache folder. The profiling folder now contains a `package.json` file with references to the package. In short, all those profiles are now ready to be used in Forge!

* 	Add the extension to the ImmunizationProfile. Select your profile, go to the Element Tree view and select the Immunization root element. Click the extend button and find the extension. 
*   Give the extension a proper (slice)name, like 'vaccinationProcedure'.
*   Make the extension mandatory.

## Step: 2.2: Create a simple extension and add it to ImmunizationProfile
The Immunization resource does not contain a reference to the Medication resource. We are going to create our own extension to add this reference.

*	In Forge, select the profiling folder and click on New Extension. In the new screen that pops up, select 'Extension definition' in the left menu and use the 'profiles-types.xml'.
*   Similiar to the ImmunizationProfile, the extension needs at least some basic metadata such as a canonical URL, a name and description. See the table below for example values.
*   It is mandatory to provide the extension context. This element indicates where the extension is allowed to be used. You can set this in the 'Properties' tab of the extension. (Tip: the Context element is at the bottom.) 

|Metadata|value|
|-
|URL|http://`<yourname>`.`<yourcountrycode >`/fhir/StructureDefinition/`<profile name>`|
|Resource ID|extension-administeredproduct|
|Name|ExtensionAdministeredProduct|
|Title|Vaccination Product Administered|
|Description|A reference to the Medication resouce to provide details about the product administered during a vaccination event.|
|Context| `Type` = 'element' and `Expression` = 'Immunization'|

*   Profile the extension so that provides a reference element to a Medication resource.
*   Step by step: click `value[x]`, uncheck all data types, check the Reference datatype and expand it. Here you can provide the Medication URL ('http://hl7.org/fhir/StructureDefinition/Medication') in the Target Profiles. 
*	Add the extension to ImmunizationProfile, on a similar  basis as with step 2.1

## Step 2.3: Publish the extension and the updated ImmunizationProfile to Simplifier.net
Let's upload the extension and the updated ImmunizationProfile to Simplifier.net and check if everything works as expected.

Likely Simplifier will complain that it cannot resolve ExtensionUKCoreVaccinationProcedure. For this, you should add a project dependency to the `Uk.Core.r4` package. Go to the dependency tab, hit the green manage button, find and add the package.  


<div class="panel-group">
  <div class="panel panel-default">
    <div class="panel-heading">
      <h2 class="panel-title">
        <a data-toggle="collapse" href="#collapse3">Results after completing step 2</a>
      </h2>
    </div>
    <div id="collapse3" class="panel-collapse collapse">
      <div class="panel-body">
     	<h3>Differential view of ImmunizationProfile</h3>
            {{tree:https://fhir.devdays.com/R4/StructureDefinition/ImmunizationProfile-step2-extension, diff}}
 
    	<h3>Differential view of ExtensionAdministeredProduct</h3>
            {{tree:acme-profiling-tutorial-r4/extensionadministeredproduct, diff}}
 
  </div>
</div>

[1]: https://registry.fhir.org/results?query=%22Vaccination+Procedure%22&fhirVersionFilter=%5B%22R4%22%5D&latestFilter=true "A search for Vaccination Procedure on the HL7 FHIR registry"
[2]: https://simplifier.net/search?text=vaccination|procedure|uk&fhirVersion=R4 "A search for Vaccination Procedure on Simplifier.net FHIR registry"
[3]: https://simplifier.net/resolve?fhirVersion=R4&scope=UK.Core.r4@1.3.0&target=simplifier&canonical=https://fhir.nhs.uk/R4/StructureDefinition/Extension-UKCore-VaccinationProcedure

