---
topic: Slicing2
---
# Step 4:  Slicing ✂️🍕

<ul class="roundbox">
<p>The medicine regulatory authority (MRA) has additinoal requirments that require a little bit more advance profiling. The following requirements are made:</p>
<ol>
<li>The MRA has specific implementation comments for the use of the String and DateTime datatypes of the vaccine administration date. </li>
<li>Only coded values from SNOMED as defined in the International Patient Summery VaccinesGpsUvIpsv ValueSet or WHO ATC codes can be used to indicate the administrated vaccine product. </li>
</ol>
</ul>

Slicing is useful when constraints need to be made that do not necessarily apply to the whole element. In this case, it would be best to slice the element first and then apply constraints to the slices individually. This allows you to define different constraints to each slice of a single element, thereby further customizing your profile. 

## Step 4.1: Create a type slice for `occurrence[x]`
A common form of slicing is so-called type slices. FHIR resources often contain polymorphic elements which are indicated with the `[x]` at the end (i.e. `Observation.value[X]` and the `Immunization.occurcence[X]`).

In this step, we are going to place a comment in both the slice for DateTime and the slice for String. You could consider other constraints as well, such as indicating a maximum string length for String or a minimum date for DateTime.

* First, we have to slice the `occurrence[x]` element by selecting it and clicking the Slice button on top.
* Add two slices with the button next to it.
* Forge throws errors at you now because the slices don't have a name and it's own type. Let's solve that by specializing each slice with a specific type. Forge will then automatically assign the slice names occurrenceDateTime en occurrenceString to the slice. 
* Note that Forge reconizes that this is a type slice and prefils the slicing details in the  `occurrence[x]` element with `Type` = 'type' and `Path` = '$this'. 
* Finally, add implementation comments for the slices. For example, the String data type should only be used in the rare event that the DateTime is not known with of patient self-administered dose. Or you can be creative and add other constraints.


<b>Note:</b> this isn't the best example of a type slice because the implementation comments we are adding could have been made clear on the `occurrence[x]` element without slicing. It does however simulate how to profile an element in multiple ways. 


## Step 4.2: Bind multiple ValueSets to `vaccineCode`
The International Patient Summary defines the following two ValueSets that we will reuse in the ImmunizationProfile: [VaccinesGpsUvIps][1] and [WhoAtcUvIps][2]. As slicing can only be done on repeating elements (or polymorphic elements), we will slice the `vaccineCode.coding` because coding is 0..*.

* Remove the previous made cardinality constraints so the pencil icon disappears.
* Perform the same procedure as in step 4.1 (create two slices). 
* Provide the slices with the names of ValueSets
* Let's get rid of the error by providing the right slicing details at `vaccineCode.coding`. This time we are creating a slicing definition based on the binding ValueSets. In other words, the slices are discriminated by the codes inside bound ValueSets. We should let the validator logic know how it can discriminate between the slices by providing the slicing details: `Type` = 'value' and `Path` = '$this'. Forge does not show the $this option in the dropdown, but you can type it in. The equivalent for $this is the element you are in, this case `coding`. The FHIR spec provides a lot of [information on slice discriminators][3].
* Next, we will add the ValueSet bindings to the sliced elements. Provide the ValueSet's URL in the ValueSet reference box. 
* Set the binding strength to 'required'. This is important for slices based on bound ValueSets. Without the required strength, the validator cannot validate the instance because it cannot confirm if the provided code belongs to one of the bound ValueSets.
* Lastly, set the cardinality of `vaccineCode.coding` to 1..* so at least a coded value of one of these ValueSets needs to be given.


## Step 4.3: Publish the updated ImmunizationProfile to Simplifier.net
This step should be familiar by now! 😊 Update your profile and compare it with the results here below.

<div class="panel-group">
  <div class="panel panel-default">
    <div class="panel-heading">
      <h2 class="panel-title">
        <a data-toggle="collapse" href="#collapse-step4">Results after completing step 4</a>
      </h2>
    </div>
    <div id="collapse-step4" class="panel-collapse collapse">
      <div class="panel-body">
     	<h3>Differential view of ImmunizationProfile</h3>
            {{tree:https://fhir.devdays.com/R4/StructureDefinition/ImmunizationProfile, diff}}

  </div>
</div>

[1]: http://hl7.org/fhir/uv/ips/STU1/ValueSet-vaccines-gps-uv-ips.html "FHIR ValueSet: Vaccines (GPS) - IPS"
[2]: http://hl7.org/fhir/uv/ips/STU1/ValueSet-whoatc-uv-ips.html "FHIR ValueSet: 	WHO ATC - IPS"
[3]: http://hl7.org/fhir/profiling.html#discriminator "FHIR specification Slice Discriminator"
