---
topic: SearchParameter2
---
# Step 5: Create a SearchParameter definition 🔎
<ul class="roundbox">
<p>In the current design, the medicine regulatory authority (MRA) retrieves the vaccination information from the healthcare provider's system. The MRA wants to search administered vaccinations resources based on the detailed information of the administered product. Additionally, this allows to include the administered product in the search results without the need to perform an additional read request.</p>
</ul>

## Step 5.1: Create a SearchParameter resource with basic metadata 
We created an extension named 'ExtensionAdministeredProduct' in step 2.2. The FHIR specification defines SearchParameter resources for elements that are included in common use cases. These search parameters are listed at the bottom of every resource page. Here is the list of [SearchParameters for Immunization][1]. 

Because we added an extension, there is no SearchParameter available in the FHIR core specification. That's not a problem as we can create it ourselves with Forge! Almost all FHIR reference servers can incorporate SearchParameters, some even on the fly.  

* Select your profile folder in Forge, hit the little dropdown button next to New and select New Search Parameter.
* Forge throws a lot of warnings. Don't worry, we will get rit of them all. Start with filling in basic metadata in the properties tab: 

|Metadata|Value|
|-
|URL| http://`<yourname>`.`<yourcountrycode >`/fhir/SearchParameter/`<searchparameter name>` |
|Resource ID|searchparameter-administeredproduct|
|Name|SearchParameterAdministeredProduct|
|Description|To search (and _include) Medication resources that are referenced from the AdministeredProduct extension in Immunization.|

## Step 5.2: Provide the SearchParameter details

Continue with the required information in the SearchParameter tab.

* Provide a `Code`. This code is used in the API Search URLs and should not overlap one of the existing SearchParamater codes for Immunization. 
* Click on the blue plus sign at `Base` to indicate the base resources this parameter applies.
* State the data type of SearchParameter value in the dropdown at `Type`.
* Last but certainly not least: `Expression`. The SearchParameter needs precisely states what to search on. Provide the following FHIRPath expression to search on the previously created extension: <pre>Immunization.extension('[extension URL]')</pre>

That's it! You have created your own SearchParameter to extend the core FHIR API. You can test if it works by creating instances of the FHIR profiles, import all the conformance resources and play around with a HTTP tool such as Postman. This is however out of scope for this exercise. There is only one step left! 

## Step 5.3: Publish the SearchParameter to Simplifier.net
This is the last step! Well done. Compare your results with the SearchParameter here below.

<div class="panel-group">
  <div class="panel panel-default">
    <div class="panel-heading">
      <h2 class="panel-title">
        <a data-toggle="collapse" href="#collapse-step5">Results after completing step 5</a>
      </h2>
    </div>
    <div id="collapse-step5" class="panel-collapse collapse">
      <div class="panel-body">
     	<h3>JSON view of SearchParameter AdministeredProduct</h3>
            {{json:https://fhir.devdays.com/R4/SearchParameter/AdministeredProduct}} 
  </div>
</div>

[1]: http://hl7.org/fhir/immunization.html#search "Immunization SearchParameters"
